@@ -70,8 +70,8 @@
                                verbose = TRUE) {
   # check that only one level is provided
   levelName = unique(itemsToCreate$level)
-  if(length(levelName) > 1){
-    stop("'itemsToCreate' contains multiple levels! The created ITEMs have to be on the same level!")
+  if(length(levelName) > 1 || length(levelName) < 1) {
+    stop("'itemsToCreate' contains multiple levels or none at all! The created ITEMs have to be on the same level!")
   }
   
   # check that only one attribute is provided (currenlty only single attributes allowed)
@@ -275,7 +275,7 @@
                           paste0(last_items$bundle, bundle.dir.suffix),
                           paste0(last_items$bundle, ".wav"))
     
-    itemsToCreate[is.na(itemsToCreate$sample_end),]$sample_end = sapply(wav_paths, FUN = function(wav_path){attr(wrassp::read.AsspDataObj(wav_paths), "endRecord")})
+    itemsToCreate[is.na(itemsToCreate$sample_end),]$sample_end = sapply(wav_paths, FUN = function(wav_path){attr(wrassp::read.AsspDataObj(wav_path), "endRecord")})
     
     # check if there are already any segments in bundles
     
