@@ -1272,7 +1272,7 @@ load_emuDB <- function(databaseDir,
   sessions = list_sessions(dbHandle)
   bundles = list_bundles(dbHandle)
   # add column to sessions to track if already stored
-  if(nrow(sessions) != 0){
+  if(nrow(sessions) > 0 && nrow(bundles) > 0){
     sessions$stored = FALSE
     
     # calculate bundle count
