@@ -3,10 +3,10 @@ context("init data for testing")
 path2demoData = file.path(tempdir(),"emuR_demoData")
 path2testhatFolder = file.path(tempdir(),"emuR_testthat")
 
-unlink(path2demoData, recursive = T)
-unlink(path2testhatFolder, recursive = T)
+unlink(path2demoData, recursive = TRUE)
+unlink(path2testhatFolder, recursive = TRUE)
 
-create_emuRdemoData(precache = T)
+create_emuRdemoData(precache = TRUE)
 create_BPFcollectionManipulated(path2demoData)
 
 dir.create(path2testhatFolder)
